// -*- C++ -*-

#ifndef INSETFIG_H_
#define INSETFIG_H_

#include "lyxinset.h"
#include "buffer.h"
#include "LString.h"
#include "LaTeXFeatures.h"
#include "figinset.h"
#include "figlist.h"

///
class InsetFig: public Inset {
public:
	///
	InsetFig(int tmpx, int tmpy, Buffer *);
	///
	~InsetFig();
	///
	int Ascent(LyXFont const &font) const;
	///
	int Descent(LyXFont const &font) const;
	///
	int Width(LyXFont const &font) const;
	///
	void Draw(LyXFont font, LyXScreen &scr, int baseline, float &x);
	///
	void Write(FILE *file);
	///
	void Read(LyXLex &lex);
	///
	int Latex(FILE *file, signed char fragile);
	///
	int Latex(LString &file, signed char fragile);
	/// Updates needed features for this inset.
	void Validate(LaTeXFeatures &features) const;

	/// what appears in the minibuffer when opening
	LString EditMessage() {return "Opened figure";}
	///
	void Edit(int, int);
	///
	unsigned char Editable() const;
	///
	bool Deletable() const;
	///
	Inset::Code LyxCode() const;
	///
	Inset* Clone();
	///
	void CallbackFig(long arg);
	///
	void Preview(char const *p);
	/// browse for file
	void BrowseFile();

	/// form for user input
	FD_Figure *form;
	/// width and height in pixels on screen
	int wid, hgh;
	/// width and height in postscript units (1/72 inch)
	int pswid, pshgh;
	/// width of raw figure w/o rotation
	int raw_wid;
	/// heigt of raw figure w/o rotation
	int raw_hgh;
	/// x and y coordinate in ps units
	int psx, psy;

	/// .eps file name
	LString fname;
	/// changed filename -> for recompute
	bool changedfname;

	///
	enum HWTYPE {
		///
		DEF,
		///
		CM,
		///
		IN,
		///
		PER_PAGE,
		///
		PER_COL
	};
	
	/// width and height types: 0-default, 1-cm, 2-in, 3-%of page
        /// For width, there is also: 4-% of col
	HWTYPE wtype;
	///
	HWTYPE htype;

	/// temporary w and h type
	HWTYPE twtype;
	///
	HWTYPE thtype;

	/// width and height
	float xwid, xhgh;

	/// rotation angle
	float angle;
	
	/// graphics command, latex version
	LString cmd;
	
	/// Caption for subfigure package
	LString subcaption;

	/// various flags
	int flags;
	bool subfigure : 1;
	/// figure reference
	FigureList::Figref *figure;
	/// temporary flags
	int pflags;
	bool psubfigure : 1;
private:
	///
	Buffer *owner;
	/// restore values on the form
	void RestoreForm();
	/// recompute screen params
	void Recompute();
	/// regenerate \includegraphics{} command
	void Regenerate();
	/// regenerate \inlcudegraphics{} command in temporary buffer
	void TempRegenerate();
	/// get sizes from .eps file
	void GetPSSizes();
};

#endif
